@@ -1,11 +1,11 @@
-from src.commands.list import get_list
 from src.utils.resolver import resolver
 from src.utils.export import export_json, export_yaml, export_html
-from src.utils.file_control import load_dict_from_file
+from src.utils.repository import Repository
 
 
-def run_bundle(spec_path, filename=None):
-    collection = get_list(spec_path)
+def run_bundle(spec_paths, filename=None):
+    repository = Repository(spec_paths)
+    collection = repository.routes
     if collection.len() == 0 and filename is None:
         return {}
     elif collection.len() > 0 and filename is None:
@@ -13,7 +13,7 @@ def run_bundle(spec_path, filename=None):
     elif filename is not None:
         header_file = filename
     try:
-        data = load_dict_from_file(header_file)
+        data = repository.file_control.load_dict_from_file(header_file)
         if isinstance(data, dict):
             data['paths'] = {}
             data.pop('components', None)
@@ -26,14 +26,14 @@ def run_bundle(spec_path, filename=None):
     for route in collection.get():
         if route.url not in data['paths']:
             data['paths'][route.url] = {}
-        resolved_spec = resolver(route.file, route.spec)
+        resolved_spec = resolver(route.file, route.spec, repository.file_control)
         data['paths'][route.url].update({route.method.lower(): resolved_spec})
 
     return data
 
 
-def bundle(spec_path, type, filename=None):
-    specs = run_bundle(spec_path, filename)
+def bundle(spec_paths, type, filename=None):
+    specs = run_bundle(spec_paths, filename)
     if type == 'json':
         export_json(specs)
     elif type == 'yaml':
